import { urlSafeBase64 } from '@silverhand/essentials';
import { isArbitraryObject } from './arbitrary-object.js';
import { LogtoError } from './errors.js';

/* eslint-disable complexity */
/**
 * @link [ID Token](https://openid.net/specs/openid-connect-core-1_0.html#IDToken)
 */
function assertIdTokenClaims(data) {
    if (!isArbitraryObject(data)) {
        throw new TypeError('IdToken is expected to be an object');
    }
    for (const key of ['iss', 'sub', 'aud']) {
        if (typeof data[key] !== 'string') {
            throw new TypeError(`At path: IdToken.${key}: expected a string`);
        }
    }
    for (const key of ['exp', 'iat']) {
        if (typeof data[key] !== 'number') {
            throw new TypeError(`At path: IdToken.${key}: expected a number`);
        }
    }
    for (const key of ['at_hash', 'name', 'username', 'picture', 'email', 'phone_number']) {
        if (data[key] === undefined) {
            continue;
        }
        if (typeof data[key] !== 'string' && data[key] !== null) {
            throw new TypeError(`At path: IdToken.${key}: expected null or a string`);
        }
    }
    for (const key of ['email_verified', 'phone_number_verified']) {
        if (data[key] === undefined) {
            continue;
        }
        if (typeof data[key] !== 'boolean') {
            throw new TypeError(`At path: IdToken.${key}: expected a boolean`);
        }
    }
}
/* eslint-enable complexity */
const decodeIdToken = (token) => {
    const { 1: encodedPayload } = token.split('.');
    if (!encodedPayload) {
        throw new LogtoError('id_token.invalid_token');
    }
    const json = urlSafeBase64.decode(encodedPayload);
    const idTokenClaims = JSON.parse(json);
    assertIdTokenClaims(idTokenClaims);
    return idTokenClaims;
};

export { decodeIdToken };
